# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.i18n.models import I18n
from jmb.core.admin import dashboard as jmb_dashboard

class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': "I18n",
            'display': "tabs",
            'children': [
                CustomModule(
                    title='Today I18n',
                    order_by='-date_create',
                    limit=None,
                    extra_filters={'date_create__gte': today},
                ),
                Models(),
                OtherModels(),
#                I18nSettings(),
                Permissions(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)

class I18nDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': "I18n",
            'display': "tabs",
            'children': [
                Models(),
                OtherModels(),
#                Settings(),
                Permissions(),
            ]
        }
        super(I18nDashboard, self).__init__(**kwargs)

class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Main Models"),
            'models': ('jmb.i18n.models.I18n',),
        }
        super(Models, self).__init__(**kwargs)

class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Others"),
            'models': (),
        }
        super(OtherModels, self).__init__(**kwargs)

# class Settings(modules.ModelList):
#     def __init__(self, **kwargs):
#         kwargs =  {
#             'title': _("Settings"),
#             'models':['jmb.i18n.models.Settings',],
#             }
#         super(Settings, self).__init__(**kwargs)

class Permissions(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Permissions"),
            'models':['jmb.i18n.models.I18nPermissions',],
        }
        super(Permissions, self).__init__(**kwargs)

class CustomModule(modules.DashboardModule):
    """Esempio di modulo che produce contentuto generico
    """
    def __init__(self, title, template='admin_tools/i18n/custom.html',
                 order_by=None, limit=10, qs=I18n.objects.all(), extra_filters={},
                 children=None, **kwargs):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(CustomModule, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs


class DefaultAppDashboard(AppIndexDashboard):
#    class Media:
#        css = ('office_thunder/css/dashboard.css',)
#
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 2

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(I18nDashboard, 'jmb.i18n')
# Used in /admin/I18n
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.i18n')
